@@ -15,66 +15,48 @@
 # limitations under the License.
 #
 
-from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OUnsupervisedAlgorithm import H2OUnsupervisedAlgorithm
-from ai.h2o.sparkling.ml.models.H2OKMeansMOJOModel import H2OKMeansMOJOModel
-from ai.h2o.sparkling.ml.params.H2OKMeansParams import H2OKMeansParams
-from ai.h2o.sparkling.ml.algos.H2OKMeansExtras import H2OKMeansExtras
+from ai.h2o.sparkling.ml.algos.H2OUnsupervisedAlgoBase import H2OUnsupervisedAlgoBase
+from ai.h2o.sparkling.ml.params import H2OKMeansParams
 
 
-class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
+class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgoBase):
 
     @keyword_only
     def __init__(self,
-                 userPoints=None,
-                 ignoredCols=None,
-                 columnsToCategorical=[],
-                 keepBinaryModels=False,
-                 withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
-                 withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
-                 convertInvalidNumbersToNa=False,
-                 detailedPredictionCol="detailed_prediction",
-                 validationDataFrame=None,
-                 featuresCols=[],
-                 predictionCol="prediction",
-                 convertUnknownCategoricalLevelsToNa=False,
-                 splitRatio=1.0,
-                 withStageResults=False,
                  maxIterations=10,
                  standardize=True,
-                 seed=-1,
                  init="Furthest",
+                 userPoints=None,
                  estimateK=False,
-                 clusterSizeConstraints=None,
-                 k=1,
+                 k=2,
                  modelId=None,
-                 nfolds=0,
-                 keepCrossValidationModels=True,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationFoldAssignment=False,
+                 parallelizeCrossValidation=True,
+                 distribution="AUTO",
                  foldCol=None,
-                 foldAssignment="AUTO",
-                 categoricalEncoding="AUTO",
-                 ignoreConstCols=True,
-                 scoreEachIteration=False,
-                 maxRuntimeSecs=0.0,
-                 exportCheckpointsDir=None):
+                 weightCol=None,
+                 splitRatio=1.0,
+                 seed=-1,
+                 nfolds=0,
+                 allStringColumnsToCategorical=True,
+                 columnsToCategorical=[],
+                 predictionCol="prediction",
+                 detailedPredictionCol="detailed_prediction",
+                 withDetailedPredictionCol=True,
+                 featuresCols=[],
+                 convertUnknownCategoricalLevelsToNa=False,
+                 convertInvalidNumbersToNa=False,
+                 namedMojoOutputColumns=True,
+                 withContributions=False,
+                 withLeafNodeAssignments=False):
         Initializer.load_sparkling_jar()
         super(H2OKMeans, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OKMeans", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
-
-        if 'interactionPairs' in kwargs:
-            warn("Interaction pairs are not supported!")
         self._set(**kwargs)
-        self._transfer_params_to_java()
-
-    def _create_model(self, javaModel):
-        return H2OKMeansMOJOModel(javaModel)
